You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@groovy.apache.org by pa...@apache.org on 2015/10/21 22:39:26 UTC

[2/2] incubator-groovy git commit: testThreadInterrupt sometimes fails on builds.apache.org so give it some more time

testThreadInterrupt sometimes fails on builds.apache.org so give it some more time


Project: http://git-wip-us.apache.org/repos/asf/incubator-groovy/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-groovy/commit/cb8caaf9
Tree: http://git-wip-us.apache.org/repos/asf/incubator-groovy/tree/cb8caaf9
Diff: http://git-wip-us.apache.org/repos/asf/incubator-groovy/diff/cb8caaf9

Branch: refs/heads/master
Commit: cb8caaf9bcce468a3af10fbf6d736a074414bcec
Parents: 98cbf97
Author: pascalschumacher <pa...@gmx.net>
Authored: Wed Oct 21 22:38:52 2015 +0200
Committer: pascalschumacher <pa...@gmx.net>
Committed: Wed Oct 21 22:38:52 2015 +0200

----------------------------------------------------------------------
 src/spec/test/SaferScriptingASTTransformsTest.groovy | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-groovy/blob/cb8caaf9/src/spec/test/SaferScriptingASTTransformsTest.groovy
----------------------------------------------------------------------
diff --git a/src/spec/test/SaferScriptingASTTransformsTest.groovy b/src/spec/test/SaferScriptingASTTransformsTest.groovy
index 2b8a82d..55ff72b 100644
--- a/src/spec/test/SaferScriptingASTTransformsTest.groovy
+++ b/src/spec/test/SaferScriptingASTTransformsTest.groovy
@@ -53,7 +53,7 @@ while (true) {
 def t = Thread.start {
     shell.evaluate(userCode)
 }
-t.join(500) // give at most 500ms for the script to complete
+t.join(1000) // give at most 1000ms for the script to complete
 if (t.alive) {
     t.interrupt()
 }